@@ -5,16 +5,14 @@
 # @Email    : 376355670@qq.com
 from asyncio import iscoroutine, isfuture, Task
 
-from ._types import Lang
 
-
-def is_coroutine(value: Lang) -> bool:
+def is_coroutine(value) -> bool:
     return iscoroutine(value)
 
 
-def is_future(value: Lang) -> bool:
+def is_future(value) -> bool:
     return isfuture(value)
 
 
-def is_coroutine_task(value: Lang) -> bool:
+def is_task(value) -> bool:
     return isinstance(value, Task)
