@@ -3,8 +3,6 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
-from ._types import Lang
 
-
-def is_py_empty(value: Lang) -> bool:
+def is_empty(value) -> bool:
     return not value
