@@ -4,14 +4,11 @@
 # @Author   : Angel
 # @Email    : 376355670@qq.com
 from asyncio import iscoroutinefunction
-from collections.abc import Callable
-
-from ._types import Lang
 
 
-def is_function(value: Lang) -> bool:
-    return isinstance(value, Callable)
+def is_function(value) -> bool:
+    return callable(value)
 
 
-def is_async_function(value: Lang) -> bool:
+def is_async_function(value) -> bool:
     return iscoroutinefunction(value)
