@@ -3,12 +3,9 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
-from ._types import Lang
-
-
-def is_null(value: Lang) -> bool:
+def is_null(value) -> bool:
     return value is None
 
 
-def is_not_null(value: Lang) -> bool:
+def is_not_null(value) -> bool:
     return not is_null(value)
