@@ -3,12 +3,9 @@
 # @IDE      : PyCharm
 # @Author   : Angel
 # @Email    : 376355670@qq.com
-from ._types import Lang
-
-
-def is_bytes(value: Lang) -> bool:
+def is_bytes(value) -> bool:
     return isinstance(value, bytes)
 
 
-def is_bytearray(value: Lang) -> bool:
+def is_bytearray(value) -> bool:
     return isinstance(value, bytearray)
